@@ -1537,6 +1537,24 @@ class OmixAtlas:
         except Exception as err:
             raise err
 
+    @Track.track_decorator
+    def download_linked_reports(self, repo_key: str, dataset_id: str, folder_path: str):
+        """Downloads Linked Reports to the repo
+
+        Args:
+            repo_key (str): repo_name/repo_id of the repository for which to fetch the report
+            dataset_id (str): dataset_id of the dataset which to fetch the reports.
+            folder_path (str): local folder path where the files need to be downloaded
+
+        Returns:
+            Downloads the datasets in the passed folder path
+        """
+        try:
+            report_obj = Reporting()
+            report_obj.download_linked_reports(self, repo_key, dataset_id, folder_path)
+        except Exception as err:
+            raise err
+
     @Track.track_decorator
     def delete_linked_report(
         self, repo_key: str, dataset_id: str, report_id: str
